Class: Wavefront::Event

Inherits:
CoreApi show all
Includes:
Mixin::Tag
Defined in:
lib/wavefront-sdk/event.rb

Overview

View and manage events. Events are identified by their millisecond epoch timestamp.

Instance Attribute Summary

Attributes inherited from CoreApi

#api, #creds, #logger, #opts

Instance Method Summary collapse

Methods included from Mixin::Tag

#tag_add, #tag_delete, #tag_set, #tags

Methods inherited from CoreApi

#api_base, #api_path, #hash_for_update, #initialize, #setup_api, #time_to_ms

Methods included from Mixins

#log, #parse_relative_time, #parse_time, #relative_time, #time_multiplier, #valid_relative_time?

Methods included from Validators

#uuid?, #wf_alert_id?, #wf_alert_severity?, #wf_apitoken_id?, #wf_cloudintegration_id?, #wf_dashboard_id?, #wf_derivedmetric_id?, #wf_distribution?, #wf_distribution_count?, #wf_distribution_interval?, #wf_distribution_values?, #wf_epoch?, #wf_event_id?, #wf_granularity?, #wf_integration_id?, #wf_link_id?, #wf_link_template?, #wf_maintenance_window_id?, #wf_message_id?, #wf_metric_name?, #wf_ms_ts?, #wf_name?, #wf_notificant_id?, #wf_point?, #wf_point_tag?, #wf_point_tags?, #wf_proxy_id?, #wf_savedsearch_entity?, #wf_savedsearch_id?, #wf_source_id?, #wf_string?, #wf_tag?, #wf_ts?, #wf_user_id?, #wf_usergroup_id?, #wf_value?, #wf_version?, #wf_webhook_id?

Constructor Details

This class inherits a constructor from Wavefront::CoreApi

Instance Method Details

#close(id) ⇒ Object

POST /api/v2/event/id/close Close a specific event.



116
117
118
119
# File 'lib/wavefront-sdk/event.rb', line 116

def close(id)
  wf_event_id?(id)
  api.post([id, 'close'].uri_concat)
end

#create(body) ⇒ Wavefront::Response

POST /api/v2/event Create a specific event.

We used to validate keys and provide helpers for time fields. Now ensuring a valid hash is entirely left up to the user. Refer to the Swagger docs for more information.

Raises:

  • (ArgumentError)


57
58
59
60
# File 'lib/wavefront-sdk/event.rb', line 57

def create(body)
  raise ArgumentError unless body.is_a?(Hash)
  api.post('', body, 'application/json')
end

#delete(id) ⇒ Wavefront::Response

DELETE /api/v2/event/id Delete a specific event.



68
69
70
71
# File 'lib/wavefront-sdk/event.rb', line 68

def delete(id)
  wf_event_id?(id)
  api.delete(id)
end

#describe(id, version = nil) ⇒ Wavefront::Response

GET /api/v2/event/id Get a specific event / Get a specific historical version of a specific event.



81
82
83
84
85
86
87
# File 'lib/wavefront-sdk/event.rb', line 81

def describe(id, version = nil)
  wf_event_id?(id)
  wf_version?(version) if version
  fragments = [id]
  fragments += ['history', version] if version
  api.get(fragments.uri_concat)
end

#list(from = nil, to = Time.now, limit = 100, cursor = nil) ⇒ Wavefront::Response

GET /api/v2/event List all the events for a customer within a time range.

Raises:

  • (ArgumentError)


29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/wavefront-sdk/event.rb', line 29

def list(from = nil, to = Time.now, limit = 100, cursor = nil)
  raise ArgumentError unless from && to
  wf_event_id?(cursor) if cursor

  from = parse_time(from, true)
  to   = parse_time(to, true)

  wf_ms_ts?(from)
  wf_ms_ts?(to)

  body = { earliestStartTimeEpochMillis: from,
           latestStartTimeEpochMillis:   to,
           cursor:                       cursor,
           limit:                        limit }

  api.get('', body.cleanse)
end

#update(id, body, modify = true) ⇒ Wavefront::Response

PUT /api/v2/event/id Update a specific event

This method helps you update one or more properties of an event.

Raises:

  • (ArgumentError)


102
103
104
105
106
107
108
109
# File 'lib/wavefront-sdk/event.rb', line 102

def update(id, body, modify = true)
  wf_event_id?(id)
  raise ArgumentError unless body.is_a?(Hash)

  return api.put(id, body, 'application/json') unless modify

  api.put(id, hash_for_update(describe(id), body), 'application/json')
end

#update_keysObject



12
13
14
# File 'lib/wavefront-sdk/event.rb', line 12

def update_keys
  i[startTime endTime name annotations]
end

#valid_id?(id) ⇒ Boolean



121
122
123
# File 'lib/wavefront-sdk/event.rb', line 121

def valid_id?(id)
  wf_event_id?(id)
end