Class: Wavefront::Event
Overview
View and manage events. Events are identified by their millisecond epoch timestamp.
Instance Attribute Summary
Attributes inherited from Base
#conn, #debug, #logger, #net, #noop, #opts, #verbose
Instance Method Summary collapse
-
#close(id) ⇒ Object
POST /api/v2/event/id/close Close a specific event.
-
#create(body) ⇒ Wavefront::Response
POST /api/v2/event Create a specific event.
-
#delete(id) ⇒ Wavefront::Response
DELETE /api/v2/event/id Delete a specific event.
-
#describe(id, version = nil) ⇒ Wavefront::Response
GET /api/v2/event/id Get a specific event / Get a specific historical version of a specific event.
-
#list(from = nil, to = nil, limit = 100, cursor = nil) ⇒ Wavefront::Response
GET /api/v2/event List all the events for a customer within a time range.
-
#tag_add(id, tag) ⇒ Wavefront::Response
PUT /api/v2/event/id/tag/tagValue Add a tag to a specific event.
-
#tag_delete(id, tag) ⇒ Wavefront::Response
DELETE /api/v2/event/id/tag/tagValue Remove a tag from a specific event.
-
#tag_set(id, tags) ⇒ Wavefront::Response
POST /api/v2/event/id/tag Set all tags associated with a specific event.
-
#tags(id) ⇒ Wavefront::Response
GET /api/v2/event/id/tag Get all tags associated with a specific event.
-
#update(id, body, modify = true) ⇒ Wavefront::Response
PUT /api/v2/event/id Update a specific event.
- #update_keys ⇒ Object
Methods inherited from Base
#api_base, #api_delete, #api_get, #api_path, #api_post, #api_put, #everything, #hash_for_update, #initialize, #log, #mk_conn, #print_message, #respond, #time_to_ms
Methods included from Mixins
#parse_relative_time, #parse_time, #relative_time, #time_multiplier
Methods included from Validators
#wf_alert_id?, #wf_alert_severity?, #wf_cloudintegration_id?, #wf_dashboard_id?, #wf_derivedmetric_id?, #wf_epoch?, #wf_event_id?, #wf_granularity?, #wf_integration_id?, #wf_link_id?, #wf_link_template?, #wf_maintenance_window_id?, #wf_message_id?, #wf_metric_name?, #wf_ms_ts?, #wf_name?, #wf_notificant_id?, #wf_point?, #wf_point_tag?, #wf_point_tags?, #wf_proxy_id?, #wf_savedsearch_entity?, #wf_savedsearch_id?, #wf_source_id?, #wf_string?, #wf_tag?, #wf_ts?, #wf_user_id?, #wf_value?, #wf_version?, #wf_webhook_id?
Constructor Details
This class inherits a constructor from Wavefront::Base
Instance Method Details
#close(id) ⇒ Object
POST /api/v2/event/id/close Close a specific event.
109 110 111 112 |
# File 'lib/wavefront-sdk/event.rb', line 109 def close(id) wf_event_id?(id) api_post([id, 'close'].uri_concat) end |
#create(body) ⇒ Wavefront::Response
POST /api/v2/event Create a specific event.
We used to validate keys and provide helpers for time fields. Now ensuring a valid hash is entirely left up to the user. Refer to the Swagger docs for more information.
50 51 52 53 |
# File 'lib/wavefront-sdk/event.rb', line 50 def create(body) raise ArgumentError unless body.is_a?(Hash) api_post('', body, 'application/json') end |
#delete(id) ⇒ Wavefront::Response
DELETE /api/v2/event/id Delete a specific event.
61 62 63 64 |
# File 'lib/wavefront-sdk/event.rb', line 61 def delete(id) wf_event_id?(id) api_delete(id) end |
#describe(id, version = nil) ⇒ Wavefront::Response
GET /api/v2/event/id Get a specific event / Get a specific historical version of a specific event.
74 75 76 77 78 79 80 |
# File 'lib/wavefront-sdk/event.rb', line 74 def describe(id, version = nil) wf_event_id?(id) wf_version?(version) if version fragments = [id] fragments += ['history', version] if version api_get(fragments.uri_concat) end |
#list(from = nil, to = nil, limit = 100, cursor = nil) ⇒ Wavefront::Response
GET /api/v2/event List all the events for a customer within a time range.
26 27 28 29 30 31 32 33 34 35 36 37 38 |
# File 'lib/wavefront-sdk/event.rb', line 26 def list(from = nil, to = nil, limit = 100, cursor = nil) raise ArgumentError unless from && to from = parse_time(from, true) to = parse_time(to, true) wf_ms_ts?(from) wf_ms_ts?(to) wf_event_id?(cursor) if cursor raise ArgumentError unless limit.is_a?(Integer) api_get('', { earliestStartTimeEpochMillis: from, latestStartTimeEpochMillis: to, cursor: cursor, limit: limit }.select { |_k, v| v }) end |
#tag_add(id, tag) ⇒ Wavefront::Response
PUT /api/v2/event/id/tag/tagValue Add a tag to a specific event.
161 162 163 164 165 |
# File 'lib/wavefront-sdk/event.rb', line 161 def tag_add(id, tag) wf_event_id?(id) wf_string?(tag) api_put([id, 'tag', tag].uri_concat) end |
#tag_delete(id, tag) ⇒ Wavefront::Response
DELETE /api/v2/event/id/tag/tagValue Remove a tag from a specific event.
148 149 150 151 152 |
# File 'lib/wavefront-sdk/event.rb', line 148 def tag_delete(id, tag) wf_event_id?(id) wf_string?(tag) api_delete([id, 'tag', tag].uri_concat) end |
#tag_set(id, tags) ⇒ Wavefront::Response
POST /api/v2/event/id/tag Set all tags associated with a specific event.
134 135 136 137 138 139 |
# File 'lib/wavefront-sdk/event.rb', line 134 def tag_set(id, ) wf_event_id?(id) = Array() .each { |t| wf_string?(t) } api_post([id, 'tag'].uri_concat, , 'application/json') end |
#tags(id) ⇒ Wavefront::Response
GET /api/v2/event/id/tag Get all tags associated with a specific event
121 122 123 124 |
# File 'lib/wavefront-sdk/event.rb', line 121 def (id) wf_event_id?(id) api_get([id, 'tag'].uri_concat) end |
#update(id, body, modify = true) ⇒ Wavefront::Response
PUT /api/v2/event/id Update a specific event
This method helps you update one or more properties of an event.
95 96 97 98 99 100 101 102 |
# File 'lib/wavefront-sdk/event.rb', line 95 def update(id, body, modify = true) wf_event_id?(id) raise ArgumentError unless body.is_a?(Hash) return api_put(id, body, 'application/json') unless modify api_put(id, hash_for_update(describe(id), body), 'application/json') end |
#update_keys ⇒ Object
9 10 11 |
# File 'lib/wavefront-sdk/event.rb', line 9 def update_keys %i[startTime endTime name annotations] end |