Class: Wavefront::Type::Status
- Inherits:
-
Object
- Object
- Wavefront::Type::Status
- Defined in:
- lib/wavefront-sdk/response.rb
Overview
An object which provides information about whether the request was successful or not. Ordinarily this is easy to construct from the API’s JSON response, but some classes, for instance Wavefront::Write fake it by constructing their own.
Instance Attribute Summary collapse
-
#code ⇒ Integer
readonly
The HTTP response code from the API request.
-
#message ⇒ String
readonly
Any informational message from the API.
-
#result ⇒ OK, ERROR
readonly
A string telling us how the request went.
Instance Method Summary collapse
-
#initialize(raw, status) ⇒ Status
constructor
A new instance of Status.
Constructor Details
#initialize(raw, status) ⇒ Status
Returns a new instance of Status.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/wavefront-sdk/response.rb', line 87 def initialize(raw, status) obj = raw.key?(:status) ? raw[:status] : raw @message = obj[:message] || nil @code = obj[:code] || status @result = if obj[:result] obj[:result] elsif status >= 200 && status <= 299 'OK' else 'ERROR' end end |
Instance Attribute Details
#code ⇒ Integer (readonly)
Returns the HTTP response code from the API request.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/wavefront-sdk/response.rb', line 81 class Status attr_reader :result, :message, :code # @param raw [Hash] the API response, turned into a hash # @param status [Integer] HTTP status code # def initialize(raw, status) obj = raw.key?(:status) ? raw[:status] : raw @message = obj[:message] || nil @code = obj[:code] || status @result = if obj[:result] obj[:result] elsif status >= 200 && status <= 299 'OK' else 'ERROR' end end end |
#message ⇒ String (readonly)
Returns Any informational message from the API.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/wavefront-sdk/response.rb', line 81 class Status attr_reader :result, :message, :code # @param raw [Hash] the API response, turned into a hash # @param status [Integer] HTTP status code # def initialize(raw, status) obj = raw.key?(:status) ? raw[:status] : raw @message = obj[:message] || nil @code = obj[:code] || status @result = if obj[:result] obj[:result] elsif status >= 200 && status <= 299 'OK' else 'ERROR' end end end |
#result ⇒ OK, ERROR (readonly)
Returns a string telling us how the request went.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/wavefront-sdk/response.rb', line 81 class Status attr_reader :result, :message, :code # @param raw [Hash] the API response, turned into a hash # @param status [Integer] HTTP status code # def initialize(raw, status) obj = raw.key?(:status) ? raw[:status] : raw @message = obj[:message] || nil @code = obj[:code] || status @result = if obj[:result] obj[:result] elsif status >= 200 && status <= 299 'OK' else 'ERROR' end end end |