Class: Wavefront::Type::Status

Inherits:
Object
  • Object
show all
Defined in:
lib/wavefront-sdk/response.rb

Overview

An object which provides information about whether the request was successful or not. Ordinarily this is easy to construct from the API’s JSON response, but some classes, for instance Wavefront::Write fake it by constructing their own.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(raw, status) ⇒ Status

Returns a new instance of Status.

Parameters:

  • raw (Hash)

    the API response, turned into a hash

  • status (Integer)

    HTTP status code



91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/wavefront-sdk/response.rb', line 91

def initialize(raw, status)
  obj = raw.key?(:status) ? raw[:status] : raw

  @message = obj[:message] || nil
  @code = obj[:code] || status

  @result = if obj[:result]
              obj[:result]
            elsif status == 200
              'OK'
            else
              'ERROR'
            end
end

Instance Attribute Details

#codeInteger (readonly)

Returns the HTTP response code from the API request.

Returns:

  • (Integer)

    the HTTP response code from the API request



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/wavefront-sdk/response.rb', line 85

class Status
  attr_reader :result, :message, :code

  # @param raw [Hash] the API response, turned into a hash
  # @param status [Integer] HTTP status code
  #
  def initialize(raw, status)
    obj = raw.key?(:status) ? raw[:status] : raw

    @message = obj[:message] || nil
    @code = obj[:code] || status

    @result = if obj[:result]
                obj[:result]
              elsif status == 200
                'OK'
              else
                'ERROR'
              end
  end
end

#messageString (readonly)

Returns Any informational message from the API.

Returns:

  • (String)

    Any informational message from the API



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/wavefront-sdk/response.rb', line 85

class Status
  attr_reader :result, :message, :code

  # @param raw [Hash] the API response, turned into a hash
  # @param status [Integer] HTTP status code
  #
  def initialize(raw, status)
    obj = raw.key?(:status) ? raw[:status] : raw

    @message = obj[:message] || nil
    @code = obj[:code] || status

    @result = if obj[:result]
                obj[:result]
              elsif status == 200
                'OK'
              else
                'ERROR'
              end
  end
end

#resultOK, ERROR (readonly)

Returns a string telling us how the request went.

Returns:

  • (OK, ERROR)

    a string telling us how the request went



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/wavefront-sdk/response.rb', line 85

class Status
  attr_reader :result, :message, :code

  # @param raw [Hash] the API response, turned into a hash
  # @param status [Integer] HTTP status code
  #
  def initialize(raw, status)
    obj = raw.key?(:status) ? raw[:status] : raw

    @message = obj[:message] || nil
    @code = obj[:code] || status

    @result = if obj[:result]
                obj[:result]
              elsif status == 200
                'OK'
              else
                'ERROR'
              end
  end
end