Class: Wavefront::Type::Status

Inherits:
Object
  • Object
show all
Defined in:
lib/wavefront-sdk/response.rb

Overview

An object which provides information about whether the request was successful or not. Ordinarily this is easy to construct from the API's JSON response, but some classes, for instance Wavefront::Write fake it by constructing their own.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(raw, status) ⇒ Status



85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/wavefront-sdk/response.rb', line 85

def initialize(raw, status)
  obj = raw.key?(:status) ? raw[:status] : raw

  @message = obj[:message] || nil
  @code = obj[:code] || status

  @result = if obj[:result]
              obj[:result]
            elsif status == 200
              'OK'
            else
              'ERROR'
            end
end

Instance Attribute Details

#codeInteger (readonly)



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/wavefront-sdk/response.rb', line 79

class Status
  attr_reader :result, :message, :code

  # @param raw [Hash] the API response, turned into a hash
  # @param status [Integer] HTTP status code
  #
  def initialize(raw, status)
    obj = raw.key?(:status) ? raw[:status] : raw

    @message = obj[:message] || nil
    @code = obj[:code] || status

    @result = if obj[:result]
                obj[:result]
              elsif status == 200
                'OK'
              else
                'ERROR'
              end
  end
end

#messageString (readonly)



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/wavefront-sdk/response.rb', line 79

class Status
  attr_reader :result, :message, :code

  # @param raw [Hash] the API response, turned into a hash
  # @param status [Integer] HTTP status code
  #
  def initialize(raw, status)
    obj = raw.key?(:status) ? raw[:status] : raw

    @message = obj[:message] || nil
    @code = obj[:code] || status

    @result = if obj[:result]
                obj[:result]
              elsif status == 200
                'OK'
              else
                'ERROR'
              end
  end
end

#resultOK, ERROR (readonly)



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/wavefront-sdk/response.rb', line 79

class Status
  attr_reader :result, :message, :code

  # @param raw [Hash] the API response, turned into a hash
  # @param status [Integer] HTTP status code
  #
  def initialize(raw, status)
    obj = raw.key?(:status) ? raw[:status] : raw

    @message = obj[:message] || nil
    @code = obj[:code] || status

    @result = if obj[:result]
                obj[:result]
              elsif status == 200
                'OK'
              else
                'ERROR'
              end
  end
end